#include <clocale>
#include <ctime>
#include <fstream>
#include "felulet.h"

using namespace std;

// Adatok
map<int, SDolgozo> g_dolgozok;
map<int, SProjekt> g_projektek;
vector<STagsag> g_tagsagok;
vector<SUzenet> g_uzenetek;

// Vrakozs billenty letsig
void Pause()
{
	system("pause");
}

// Konzol tartalmnak trlse
void CleanScreen()
{
	system("cls");
}

// A mai dtum .hh.nn formtumban
std::string MaiDatum()
{
	auto t = time(0);
	auto tm = gmtime(&t);
	char buffer[256];
	sprintf(buffer, "%04d.%02d.%02d", tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday);
	return buffer;
}

// A kvetkez fggvnyek az adatok beolvassra s mentsre vannak.
void BeolvasDolgozok()
{
	ifstream f("dolgozok.txt");

	if (!f.is_open())
	{
		cout << "A dolgozok.txt fjl beolvassa nem sikerlt" << endl;
		return;
	}

	int azonosito, vezeto;
	string nev, jelszo;

	while (f >> azonosito && f.ignore(1, ':') && getline(f, nev, ':') && getline(f, jelszo, ':') && f >> vezeto)
	{
		SDolgozo dolgozo = { nev, jelszo, vezeto == 0 ? false : true };
		g_dolgozok[azonosito] = dolgozo;
	}

	f.close();
}

void BeolvasProjektek()
{
	ifstream f("projektek.txt");

	if (!f.is_open())
	{
		cout << "A projektek.txt fjl beolvassa nem sikerlt" << endl;
		return;
	}

	int azonosito;
	string nev, kezdo_datum, befejezo_datum;
	while (f >> azonosito && f.ignore(1, ':') && getline(f, nev, ':') && getline(f, kezdo_datum, ':'))
	{
		if (!getline(f, befejezo_datum))
		{
			befejezo_datum = "";
		}
		SProjekt projekt = { nev, kezdo_datum, befejezo_datum };
		g_projektek[azonosito] = projekt;
	}

	f.close();
}

void BeolvasTagsagok()
{
	ifstream f("tagsagok.txt");

	if (!f.is_open())
	{
		cout << "A tagsagok.txt fjl beolvassa nem sikerlt" << endl;
		return;
	}

	int projekt, munkatars, vezeto;
	while (f >> projekt && f.ignore(1, ':') &&  f >> munkatars && f.ignore(1, ':') && f >> vezeto)
	{
		STagsag tagsag = { projekt, munkatars, vezeto == 0 ? false : true };
		g_tagsagok.push_back(tagsag);
	}

	f.close();
}

void BeolvasUzenetek()
{
	ifstream f("uzenetek.txt");

	if (!f.is_open())
	{
		cout << "A uzenetek.txt fjl beolvassa nem sikerlt" << endl;
		return;
	}

	int projekt, felado, cimzett;
	string datum, tartalom;
	while (f >> projekt
		&& f.ignore(1, ':')
		&& getline(f, datum, ':') 
		&& f >> felado
		&& f.ignore(1, ':')
		&& f >> cimzett
		&& f.ignore(1, ':') &&
		getline(f, tartalom))
	{
		// Az zenetek elejn egy * jelli, hogy az zenetet olvastuk-e mr
		bool olvasott = false;
		if (tartalom.length() > 1 && tartalom[0] == '*')
		{
			tartalom = tartalom.substr(1);
			olvasott = true;
		}
		SUzenet uzenet = { projekt, datum, felado, cimzett, tartalom, olvasott };
		g_uzenetek.push_back(uzenet);
	}

	f.close();
}

void MentesProjektek()
{
	ofstream f("projektek.txt");

	for (auto &projekt : g_projektek)
	{
		f << projekt.first << ":" << projekt.second.nev << ":" << projekt.second.kezdo_datum << ":" << projekt.second.befejezo_datum << endl;
	}

	f.close();
}

void MentesTagsagok()
{
	ofstream f("tagsagok.txt");

	for (auto &tagsag : g_tagsagok)
	{
		f << tagsag.projekt << ":" << tagsag.munkatars << ":" << (tagsag.vezeto ? 1 : 0) << endl;
	}

	f.close();
}

void MentesUzenetek()
{
	ofstream f("uzenetek.txt");

	for (auto &uzenet : g_uzenetek)
	{
		f << uzenet.projekt << ":" << uzenet.datum << ":"
		  << uzenet.felado << ":" << uzenet.cimzett << ":";
		
		if (uzenet.olvasott)
			f << "*";

		f << uzenet.tartalom << endl;
	}

	f.close();
}

// Bejelentkezs, s folytats a megfelel felleten
void Bejelentkezes()
{
	CleanScreen();

	string nev, jelszo;
	cout << "Nv: ";
	cin >> nev;
	cout << "Jelsz: ";
	cin >> jelszo;

	// Adatok ellenrzse
	for (auto &dolgozo : g_dolgozok)
	{
		if (dolgozo.second.nev == nev && dolgozo.second.jelszo == jelszo)
		{
			// Kvetkez fellet meghvsa
			if (dolgozo.second.vezeto)
				VezetoiFelulet(dolgozo.first);
			else
				MunkatarsiFelulet(dolgozo.first);

			return;
		}
	}
	cout << "Hibs felhasznl vagy jelsz" << endl;
	Pause();
}

int main()
{
	setlocale(LC_ALL, ""); // kezetes karakterekhez
	BeolvasDolgozok();
	BeolvasProjektek();
	BeolvasTagsagok();
	BeolvasUzenetek();
	
	while (true)
	{
		CleanScreen();
		cout<< "Vlasszon menpontot: " << endl
			<< "\t1. Bejelentkezs" << endl
			<< "\t0. Program bezrsa" << endl << endl
			<< "Menpont szma: ";

		int menu = 0;
		cin >> menu;
		cin.clear();
		cin.ignore(100, '\n');

		while ( menu != 1 && menu != 0 )
		{
			cout << "Nincs ilyen menpont: " << menu << ", vlassz msikat: " << endl;
			cin >> menu;
			cin.clear();
			cin.ignore(100, '\n');
		}

		switch (menu)
		{
		case 1:
			Bejelentkezes();
			break;
		default:
			return 0;
		}
	}
	return 0;
}
